FilterArgs class

Helper class for filtering logs

Constructors

FilterArgs(bool isResponse, dynamic data)
const

Properties

data → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
isResponse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited