TreeuseRespHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isTDesktop ↔ bool
-
getter/setter pair
- isTLandscape ↔ bool
-
getter/setter pair
- isTMobile ↔ bool
-
getter/setter pair
- isTPortrait ↔ bool
-
getter/setter pair
- isTTablet ↔ bool
-
getter/setter pair
- isTWeb ↔ bool
-
getter/setter pair
Static Methods
-
init(
double width, Orientation orientation) → void - Initialize the device type and orientation based on width and orientation
Constants
- desktopBreakpoint → const double
- mobileBreakpoint → const double
- tabletBreakpoint → const double