Trinterceptors class
Constructors
- Trinterceptors({bool logRequest = true, bool logRequestHeader = false, bool logRequestBody = false, bool logResponseHeader = false, bool logResponseBody = true, bool logError = true, bool compact = true, int maxWidth = 90, bool enabled = true, void logPrint(Object object) = print, bool filter(RequestOptions options, FilterArgs args)?})
Properties
- compact → bool
-
final
- enabled → bool
-
final
- filter → bool Function(RequestOptions options, FilterArgs args)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logError → bool
-
final
- logPrint → void Function(Object object)
-
final
- logRequest → bool
-
final
- logRequestBody → bool
-
final
- logRequestHeader → bool
-
final
- logResponseBody → bool
-
final
- logResponseHeader → bool
-
final
- maxWidth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException error, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited